TArchive class

Constructors

TArchive({required Map<String, dynamic> config, String mime = tArchiveMime, int version = tArchiveVersion, required List<TArchiveFile> files})
TArchive.createDirectory(String path, {Map<String, dynamic> config = const {'creator' : 'thanCoder'}, String mime = tArchiveMime})
factory
TArchive.createFiles(List<TArchiveFile> files, {String mime = tArchiveMime, Map<String, dynamic> config = const {'creator' : 'thanCoder'}})
factory

Properties

config Map<String, dynamic>
final
coverImage Uint8List?
getter/setter pair
files List<TArchiveFile>
final
hashCode int
The hash code for this object.
no setterinherited
mime String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeToFile(String path, {Uint8List? coverImage, void onProgress(String name, double progress)?}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

deleteFile(String archivePath, {required String filename}) Future<void>
readHeader(String path, {String mime = tArchiveMime}) Future<TArchiveHeader>